/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * This part of the demo creates the characters and displays a simple message. The characters are created with     * */
/* * their backs at z = 0 and extend to z = -.2. The characters are stored as an array of objects called             * */
/* * BorderCharacter [0 .. NCharacters - 1]. Each character is aligned on the left side at x = 0. An array called    * */
/* * BorderCharacterWidth [0 .. NCharacters - 1] stores the width of each character. Pay more attention to the       * */
/* * macros and the demo section...                                                                                  * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

//-f

#version 3.7;

global_settings {assumed_gamma 2.2}

#include "BorderChars.inc"

camera {
   orthographic
   location <0, 0, -13>
   direction <0, 0, 1>
   look_at <0, 0, 0>
} //camera

#local TextColor_Outer = texture {pigment {color <178, 198, 0> / 255} finish {emission 1}}
#local TextColor_Inner = texture {TextColor_Outer}
#local TextColor_Back = texture {TextColor_Outer}

#local FontVariationNumber = 0;
#local TextDepth = .2;
#local InvisibleBorderWidth = 0;
SetFontStyle (0, FontVariationNumber, TextDepth, InvisibleBorderWidth, -999, -999, -999, -999, -999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextScale = 1;
#local UseActualParagraphHeight = no;

#local NLines = 1;

InitializeVariables (NLines)

#declare LineText [0] = "Automatic Kerning Demo";

CreateParagraph (NLines, TextScale, UseActualParagraphHeight)

object {Paragraph translate <-ParagraphWidth / 2, ParagraphHeight / 2, 0>}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * MACROS REQUIRED FOR AUTOMATIC KERNING                                                                           * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#macro MeasureCharacter (I, CharacterWidth, Range_Lower, Range_Upper, Step, TestZ)

   #debug concat ("Measuring character #", str (I, 0, 0), "\n")

   #local NSteps = (abs (Range_Lower) + Range_Upper) / Step + 1;

   #local StepCount = 0;

   #for (CurY, Range_Lower, Range_Upper, Step)
      #local IntersectionPoint_LeftSide = trace (BorderCharacter [I], <-10, CurY, TestZ>, x); //Change "BorderCharacter" to the name of your array that contains the character objects.
      #if (IntersectionPoint_LeftSide.z != 0) //An intersection occured.
         #local IntersectionPoint_RightSide = trace (BorderCharacter [I], <10, CurY, TestZ>, -x); //Change "BorderCharacter" to the name of your array that contains the character objects.
         #declare SideDistance_Left [I] [StepCount] = IntersectionPoint_LeftSide.x;
         #declare SideDistance_Right [I] [StepCount] = CharacterWidth - IntersectionPoint_RightSide.x;
      #else
         #declare SideDistance_Left [I] [StepCount] = -1; //Set to -1 if no intersection.
         #declare SideDistance_Right [I] [StepCount] = -1; //Set to -1 if no intersection.
      #end //#if
      #local StepCount = StepCount + 1;
   #end //#for

   #declare CharacterMeasured [I] = true;

#end //#macro MeasureCharacter

#macro ComputeKerningValue (CharacterIndex_Left, CharacterWidth_Left, CharacterIndex_Right, CharacterWidth_Right, Range_Lower, Range_Upper, Step, Default, TestZ)

   //This macro computes the kerning value for any given pair of characters in your character set.

   //Input parameters:
   //   CharacterIndex_Left: Index number pointing to the left character
   //   CharacterWidth_Left: Width of the left character ("max_extent ().x")
   //   CharacterIndex_Right: Index number pointing to the right character
   //   CharacterWidth_Right: Width of the right character
   //   Range_Lower: The lowest y value of any character
   //   Range_Upper: The highest y value of any character
   //   Step: The step increment (resolution) of the character measurements
   //      Smaller numbers give more accuracy.
   //      Each character will be measured at vertical increments "Step" distance apart, beginning from the bottom.
   //      Care should be given to insure that key points will be evaluated, such as the baseline, x-height, and cap line.
   //   Default: Default kerning value for when the characters never coincide vertically (period and quote marks, for example)
   //   TestZ: This value indicates a point on the z axis and must be between the back and front of the character objects.
   //      A value exactly equal to the back or front of the objects may work, but somewhere in between is probably better.

   //Output:
   //   This macro returns the distance (as a positive number) that the character on the right must be moved toward the
   //      left to abut the left character.

   #if (!CharacterMeasured [CharacterIndex_Left])
      MeasureCharacter (CharacterIndex_Left, CharacterWidth_Left, Range_Lower, Range_Upper, Step, TestZ)
   #end //#if

   #if (!CharacterMeasured [CharacterIndex_Right])
      MeasureCharacter (CharacterIndex_Right, CharacterWidth_Right, Range_Lower, Range_Upper, Step, TestZ)
   #end //#if

   #local NSteps = (abs (Range_Lower) + Range_Upper) / Step + 1;

   #local MinDistance = 10;

   #local StepCount = 0;

   #for (CurY, Range_Lower, Range_Upper, Step)
      #if (SideDistance_Right [CharacterIndex_Left] [StepCount] != -1 & SideDistance_Left [CharacterIndex_Right] [StepCount] != -1)
          #local CurDistance = SideDistance_Right [CharacterIndex_Left] [StepCount] + SideDistance_Left [CharacterIndex_Right] [StepCount];
          #if (CurDistance < MinDistance)
             #local MinDistance = CurDistance;
          #end //#if
      #end //#if
      #local StepCount = StepCount + 1;
   #end //#for

   #if (MinDistance = 10)
      #local MinDistance = Default;
   #end //#if

   (abs (MinDistance));

#end //#macro ComputeKerningValue

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * THE ACTUAL DEMO                                                                                                 * */
/* *                                                                                                                 * */
/* *                                                                                                                 * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

#debug "\n\n\n* * * Begin Automatic Kerning Demo * * *\n\n"

//Set these variables: * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
#local NCharacters = 82; //The number of characters in your character set
#local Range_Lower = -.35625; //The lowest y value of any character
#local Range_Upper = 1; //The highest y value of any character
#local Step = .00025; //The step increment (resolution) of the character measurements
#local Default = .08; //Default kerning value for when the characters never coincide vertically (period and quote marks, for example)
#local TestZ = -.1; //Characters extend from z = 0 to z = -.2, so -.1 is right in the middle.
//* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

#local NSteps = (abs (Range_Lower) + Range_Upper) / Step + 1;

#declare CharacterMeasured = array [NCharacters] //Keep track of which characters have already been measured
#declare SideDistance_Left = array [NCharacters] [NSteps] //Arrays to store the character measurements
#declare SideDistance_Right = array [NCharacters] [NSteps]

//Initialize all the CharacterMeasured [] entries to false.
#for (I, 0, NCharacters - 1)
   #declare CharacterMeasured [I] = false;
#end //#for

//It is now possible to compute the kerning value for any pair of characters, a left character and a right character.

#local CharacterIndex_Left = 0; //Change these index values to see the kerning value for the characters you choose.
#local CharacterIndex_Right = 0;

#local KerningValue = ComputeKerningValue (CharacterIndex_Left, BorderCharacterWidth [CharacterIndex_Left], CharacterIndex_Right, BorderCharacterWidth [CharacterIndex_Right], Range_Lower, Range_Upper, Step, Default, TestZ)

#debug concat ("\nThe kerning value for the character pair [", str (CharacterIndex_Left, 0, 0), ", ", str (CharacterIndex_Right, 0, 0), "] = ", str (KerningValue, 0, 3), "\n\n")
